==> mindr_1.1.0.tar.gz: mindr/inst/examples/mm/bookdownplus.mm <==
<map version="1.0.1">
<node TEXT="my title">
<node TEXT="Introduction ">
<node TEXT="What is 'bookdown' "></node>
<node TEXT="What is 'bookdownplus' "></node>
<node TEXT="Why 'bookdownplus' "></node>
<node TEXT="Giants' Shoulders "></node></node>
<node TEXT="Quick Start ">
<node TEXT="Preparation "></node>
<node TEXT="Installation of 'bookdownplus' "></node>
<node TEXT="How to use "></node>
<node TEXT="More output formats"></node>
<node TEXT="More templates"></node>
<node TEXT="A magic trick"></node>
<node TEXT="Recommendations"></node></node>
<node TEXT="Basic ">
<node TEXT="Markdown Syntax ">
<node TEXT="What is Markdown "></node>
<node TEXT="Basic syntax "></node>
<node TEXT="Chapters "></node>
<node TEXT="Figures and tables "></node>
<node TEXT="References "></node>
<node TEXT="Theorems, lemma, definitions, etc. "></node>
<node TEXT="Export Word document "></node>
<node TEXT="Equations numbering "></node></node>
<node TEXT="R, RStudio and bookdown "></node>
<node TEXT="LaTeX and Pandoc "></node>
<node TEXT="Workflow "></node></node>
<node TEXT="Simple "></node>
<node TEXT="Lifestyle ">
<node TEXT="Journal "></node>
<node TEXT="Poem book "></node>
<node TEXT="Music "></node></node>
<node TEXT="Office ">
<node TEXT="Mail ">
<node TEXT="Arguments for mail content"></node>
<node TEXT="Mail themes"></node></node>
<node TEXT="Calendar "></node></node>
<node TEXT="Academic ">
<node TEXT="Articles "></node>
<node TEXT="Thesis "></node>
<node TEXT="Poster "></node>
<node TEXT="Chemistry "></node></node>
<node TEXT="Advanced ">
<node TEXT="Chinese "></node>
<node TEXT="Mind Map "></node>
<node TEXT="Create Your Own Templates "></node></node>
<node TEXT="FAQ "></node>
<node TEXT="Bibliography "></node>
</node></map>

==> mindr_1.2.3.tar.gz: mindr/inst/examples/mm/bookdownplus.mm <==
<map version="1.0.1">
<node TEXT="my title">
<node TEXT="Introduction ">
<node TEXT="What is 'bookdown' "></node>
<node TEXT="What is 'bookdownplus' " LINK="https://github.com/pzhaonet/bookdownplus" ></node>
<node TEXT="Why 'bookdownplus' "></node>
<node TEXT="Giants' Shoulders "></node></node>
<node TEXT="Quick Start ">
<node TEXT="Preparation "></node>
<node TEXT="Installation of 'bookdownplus' "></node>
<node TEXT="How to use "></node>
<node TEXT="More output formats"></node>
<node TEXT="More templates"></node>
<node TEXT="A magic trick"></node>
<node TEXT="Recommendations"></node></node>
<node TEXT="Basic ">
<node TEXT="Markdown Syntax ">
<node TEXT="What is Markdown "></node>
<node TEXT="Basic syntax "></node>
<node TEXT="Chapters "></node>
<node TEXT="Figures and tables "></node>
<node TEXT="References "></node>
<node TEXT="Theorems, lemma, definitions, etc. "></node>
<node TEXT="Export Word document "></node>
<node TEXT="Equations numbering "></node></node>
<node TEXT="R, RStudio and bookdown "></node>
<node TEXT="LaTeX and Pandoc "></node>
<node TEXT="Workflow "></node></node>
<node TEXT="Simple "></node>
<node TEXT="Lifestyle ">
<node TEXT="Journal "></node>
<node TEXT="Poem book "></node>
<node TEXT="Music "></node></node>
<node TEXT="Office ">
<node TEXT="Mail ">
<node TEXT="Arguments for mail content"></node>
<node TEXT="Mail themes"></node></node>
<node TEXT="Calendar "></node></node>
<node TEXT="Academic ">
<node TEXT="Articles "></node>
<node TEXT="Thesis "></node>
<node TEXT="Poster "></node>
<node TEXT="Chemistry "></node></node>
<node TEXT="Advanced ">
<node TEXT="Chinese "></node>
<node TEXT="Mind Map "></node>
<node TEXT="Create Your Own Templates "></node></node>
<node TEXT="FAQ "></node>
<node TEXT="Bibliography "></node>
</node></map>
